@@ -1,5 +1,5 @@
 # This file is part of RStan
-# Copyright (C) 2012, 2013, 2014, 2015 Jiqiang Guo and Benjamin Goodrich
+# Copyright (C) 2012, 2013, 2014, 2015 Trustees of Columbia University
 # Copyright (C) 2005-2010 Oleg Sklyar
 #
 # RStan is free software; you can redistribute it and/or
@@ -83,9 +83,9 @@ cxxfun_from_dso_bin <- function(dso) {
   writeBin(dso@.CXXDSOMISC$dso_bin, libLFile) 
   cleanup <- function(env) {
     if (f %in% names(getLoadedDLLs())) dyn.unload(libLFile)
-      unlink(libLFile)
+    unlink(libLFile)
   }
-  reg.finalizer(environment(), cleanup, onexit = TRUE)
+  reg.finalizer(environment(), cleanup, onexit = FALSE)
   DLL <- dyn.load(libLFile) 
   assign('dso_last_path', libLFile, dso@.CXXDSOMISC) 
   res <- vector("list", length(sig))
