@@ -1,5 +1,5 @@
 # This file is part of RStan
-# Copyright (C) 2012, 2013, 2014, 2015 Jiqiang Guo and Benjamin Goodrich
+# Copyright (C) 2012, 2013, 2014, 2015 Trustees of Columbia University
 #
 # RStan is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -79,8 +79,10 @@ stanc_builder <- function(file, isystem = dirname(file),
     header <- gsub('\\"', '', header)
     header <- gsub("\\'", '', header)
     header <- sub("[[:blank:]]*$", "", header)
-    program <- append(program, values = readLines(file.path(isystem, header)), 
-                      after = i)
+    if (file.exists(file.path(isystem, header)))
+      program <- append(program, values = readLines(file.path(isystem, header)), 
+                        after = i)
+    else program <- append(program, values = readLines(header), after = 1)
   }
   check <- grep("^[[:blank:]]*#include ", program)
   if (length(check) != length(includes))
